package com.ruoyi.business.mapper;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.core.toolkit.Constants;
import com.ruoyi.business.domain.ServiceGrant;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Update;

import java.util.List;

/**
 * 对外服务授权Mapper接口
 * 
 * @author wzq
 * @date 2024-01-10
 */
public interface ServiceGrantMapper extends BaseMapper<ServiceGrant> {

    /**
     * 查询对外服务授权
     * 
     * @param id 对外服务授权主键
     * @return 对外服务授权
     */
    ServiceGrant selectServiceGrantById(Long id);

    /**
     * 查询对外服务授权列表
     * 
     * @param outGrant 对外服务授权
     * @return 对外服务授权集合
     */
    List<ServiceGrant> selectServiceGrantList(ServiceGrant outGrant);

    /**
     * 新增对外服务授权
     * 
     * @param outGrant 对外服务授权
     * @return 结果
     */
    int insertServiceGrant(ServiceGrant outGrant);

    /**
     * 修改对外服务授权
     * 
     * @param outGrant 对外服务授权
     * @return 结果
     */
    int updateServiceGrant(ServiceGrant outGrant);

    /**
     * 删除对外服务授权
     * 
     * @param id 对外服务授权主键
     * @return 结果
     */
    int deleteServiceGrantById(Long id);

    /**
     * 批量删除对外服务授权
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteServiceGrantByIds(Long[] ids);

    /**
     * 批量删除对外服务授权（逻辑）
     * @param updateWrapper
     */
     @Update("update b_service_grant set ${ew.sqlSet} ${ew.customSqlSegment}")
     int updateByIds(@Param(Constants.WRAPPER) LambdaUpdateWrapper<ServiceGrant> updateWrapper);

    /**
     * 通过客户端id删除对外服务授权
     *
     * @param clientId 客户端id
     * @return 结果
     */
    void deleteGrantByClientId(@Param("clientId") String clientId, @Param("belongSystem") String belongSystem);

    /**
     * 通过客户端id查询已发布并且已生效的对外接口
     *
     * @param clientId 客户端id
     * @return 结果
     */
    List<ServiceGrant> selectGrantEffective(@Param("clientId") String clientId, @Param("belongSystem") String belongSystem);
}
